@@ -1,10 +1,10 @@
-/* $Id: strformat.cpp 89632 2013-10-07 21:19:37Z bird $ */
+/* $Id: strformat.cpp 102121 2015-08-14 15:16:38Z bird $ */
 /** @file
  * IPRT - String Formatter.
  */
 
 /*
- * Copyright (C) 2006-2012 Oracle Corporation
+ * Copyright (C) 2006-2015 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -25,17 +25,17 @@
  */
 
 
-/*******************************************************************************
-*   Defined Constants                                                          *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Defined Constants                                                                                                            *
+*********************************************************************************************************************************/
 #define ISDIGIT(c) ((c) >= '0' && (c) <= '9')
 /*#define MAX(a, b)  ((a) >= (b) ? (a) : (b))
 #define MIN(a, b)  ((a) < (b) ? (a) : (b)) */
 
 
-/*******************************************************************************
-*   Header Files                                                               *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Header Files                                                                                                                 *
+*********************************************************************************************************************************/
 #define LOG_GROUP RTLOGGROUP_STRING
 #include <iprt/string.h>
 #include "internal/iprt.h"
@@ -63,9 +63,9 @@ typedef struct
 } KSIZE64;
 
 
-/*******************************************************************************
-*   Internal Functions                                                         *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Internal Functions                                                                                                           *
+*********************************************************************************************************************************/
 static unsigned _strnlen(const char *psz, unsigned cchMax);
 static unsigned _strnlenUtf16(PCRTUTF16 pwsz, unsigned cchMax);
 static int rtStrFormatNumber(char *psz, KSIZE64 ullValue, unsigned int uiBase, signed int cchWidth, signed int cchPrecision, unsigned int fFlags);
@@ -181,7 +181,7 @@ static int rtStrFormatNumber(char *psz, KSIZE64 ullValue, unsigned int uiBase, s
     /*
      * Validate and adjust input...
      */
-    Assert(uiBase >= 2 || uiBase <= 16);
+    Assert(uiBase >= 2 && uiBase <= 16);
     if (fFlags & RTSTR_F_CAPITAL)
         pachDigits = "0123456789ABCDEF";
     if (fFlags & RTSTR_F_LEFT)
