@@ -1,4 +1,4 @@
-/* $Id: VBoxNetAdp-linux.c 102794 2015-09-21 15:41:19Z fmehnert $ */
+/* $Id: VBoxNetAdp-linux.c 103431 2015-10-14 17:46:19Z vushakov $ */
 /** @file
  * VBoxNetAdp - Virtual Network Adapter Driver (Host), Linux Specific Code.
  */
@@ -22,6 +22,7 @@
 #include "the-linux-kernel.h"
 #include "version-generated.h"
 #include "product-generated.h"
+#include <linux/ethtool.h>
 #include <linux/netdevice.h>
 #include <linux/etherdevice.h>
 #include <linux/miscdevice.h>
@@ -32,6 +33,7 @@
 #include <iprt/process.h>
 #include <iprt/initterm.h>
 #include <iprt/mem.h>
+#include <iprt/string.h>
 
 /*
 #include <iprt/assert.h>
@@ -71,6 +73,9 @@ static long VBoxNetAdpLinuxIOCtlUnlocked(struct file *pFilp,
                                          unsigned int uCmd, unsigned long ulArg);
 #endif /* LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 36) */
 
+static void vboxNetAdpEthGetDrvinfo(struct net_device *dev, struct ethtool_drvinfo *info);
+static int vboxNetAdpEthGetSettings(struct net_device *dev, struct ethtool_cmd *cmd);
+
 
 /*********************************************************************************************************************************
 *   Global Variables                                                                                                             *
@@ -111,6 +116,14 @@ static struct miscdevice g_CtlDev =
 # endif
 };
 
+static const struct ethtool_ops gEthToolOpsVBoxNetAdp =
+{
+    .get_drvinfo        = vboxNetAdpEthGetDrvinfo,
+    .get_settings       = vboxNetAdpEthGetSettings,
+    .get_link           = ethtool_op_get_link,
+};
+
+
 struct VBoxNetAdpPriv
 {
     struct net_device_stats Stats;
@@ -151,6 +164,51 @@ struct net_device_stats *vboxNetAdpLinuxGetStats(struct net_device *pNetDev)
     return &pPriv->Stats;
 }
 
+
+/* ethtool_ops::get_drvinfo */
+static void vboxNetAdpEthGetDrvinfo(struct net_device *pNetDev, struct ethtool_drvinfo *info)
+{
+    PVBOXNETADPPRIV pPriv = netdev_priv(pNetDev);
+
+    RTStrPrintf(info->driver, sizeof(info->driver),
+                "%s", VBOXNETADP_NAME);
+
+    /*
+     * Would be nice to include VBOX_SVN_REV, but it's not available
+     * here.  Use file's svn revision via svn keyword?
+     */
+    RTStrPrintf(info->version, sizeof(info->version),
+                "%s", VBOX_VERSION_STRING);
+
+    RTStrPrintf(info->fw_version, sizeof(info->fw_version),
+                "0x%08X", INTNETTRUNKIFPORT_VERSION);
+
+    RTStrPrintf(info->bus_info, sizeof(info->driver),
+                "N/A");
+}
+
+
+/* ethtool_ops::get_settings */
+static int vboxNetAdpEthGetSettings(struct net_device *pNetDev, struct ethtool_cmd *cmd)
+{
+    cmd->supported      = 0;
+    cmd->advertising    = 0;
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 27)
+    ethtool_cmd_speed_set(cmd, SPEED_10);
+#else
+    cmd->speed          = SPEED_10;
+#endif
+    cmd->duplex         = DUPLEX_FULL;
+    cmd->port           = PORT_TP;
+    cmd->phy_address    = 0;
+    cmd->transceiver    = XCVR_INTERNAL;
+    cmd->autoneg        = AUTONEG_DISABLE;
+    cmd->maxtxpkt       = 0;
+    cmd->maxrxpkt       = 0;
+    return 0;
+}
+
+
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 29)
 static const struct net_device_ops vboxNetAdpNetdevOps = {
     .ndo_open               = vboxNetAdpLinuxOpen,
@@ -174,6 +232,8 @@ static void vboxNetAdpNetDevInit(struct net_device *pNetDev)
     pNetDev->get_stats = vboxNetAdpLinuxGetStats;
 #endif /* LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 29) */
 
+    pNetDev->ethtool_ops = &gEthToolOpsVBoxNetAdp;
+
     pPriv = netdev_priv(pNetDev);
     memset(pPriv, 0, sizeof(*pPriv));
 }
@@ -199,6 +259,17 @@ int vboxNetAdpOsCreate(PVBOXNETADP pThis, PCRTMAC pMACAddress)
         {
             memcpy(pNetDev->dev_addr, pMACAddress, ETH_ALEN);
             Log2(("vboxNetAdpOsCreate: pNetDev->dev_addr = %.6Rhxd\n", pNetDev->dev_addr));
+
+            /*
+             * We treat presence of VBoxNetFlt filter as our "carrier",
+             * see vboxNetFltSetLinkState().
+             *
+             * operstates.txt: "On device allocation, networking core
+             * sets the flags equivalent to netif_carrier_ok() and
+             * !netif_dormant()" - so turn carrier off here.
+             */
+            netif_carrier_off(pNetDev);
+
             err = register_netdev(pNetDev);
             if (!err)
             {
